# Report

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**commit_message** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**cron** | **str** |  | [optional] 
**cron_view** | **bool** |  | [optional] 
**dashboard** | [**Dashboard**](Dashboard.md) |  | [optional] 
**decoder** | [**dict(str, ReportFieldsDecoder)**](ReportFieldsDecoder.md) |  | [optional] 
**description** | **str** |  | [optional] 
**disable_header** | **bool** |  | [optional] 
**ending_date** | **datetime** |  | [optional] 
**ending_type** | [**EndingType**](EndingType.md) |  | [optional] 
**human_cron** | [**HumanCron**](HumanCron.md) |  | [optional] 
**id** | **str** |  | [optional] 
**latest_report_name** | **str** |  | [optional] 
**latest_report_time** | **datetime** |  | [optional] 
**latest_report_username** | **str** |  | [optional] 
**latest_scheduled_report_time** | **datetime** |  | [optional] 
**locked** | **bool** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**name** | **str** |  | [optional] 
**next_scheduled_time** | **datetime** |  | [optional] 
**orientation** | **str** |  | [optional] 
**paper_size** | **str** |  | [optional] 
**prev_name** | **str** |  | [optional] 
**prev_type** | **str** |  | [optional] 
**recipients** | **list[str]** |  | [optional] 
**recurrent** | **bool** |  | [optional] 
**report_type** | **str** |  | [optional] 
**run_once** | **bool** |  | [optional] 
**running_user** | **str** |  | [optional] 
**scheduled** | **bool** | is it scheduled | [optional] 
**sections** | [**list[Section]**](Section.md) |  | [optional] 
**sensitive** | **bool** |  | [optional] 
**should_commit** | **bool** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**start_date** | **datetime** |  | [optional] 
**system** | **bool** |  | [optional] 
**tags** | **list[str]** |  | [optional] 
**times** | **int** |  | [optional] 
**timezone_offset** | **int** |  | [optional] 
**type** | **str** |  | [optional] 
**user_api_key** | **str** |  | [optional] 
**user_api_key_id** | **str** |  | [optional] 
**vc_should_ignore** | **bool** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


